@@ -1,7 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "vs-light-theme" "2.0"
+(define-package "vs-light-theme" "20251111.322"
   "Visual Studio IDE light theme."
   '((emacs "24.1"))
   :url "https://github.com/emacs-vs/vs-light-theme"
-  :commit "0e0d53d595249fa716f0a12fba3c44622132bce3"
-  :revdesc "0e0d53d59524")
+  :commit "5df4eb5df7ed6a93c4e55bc622a7ad39424bc996"
+  :revdesc "5df4eb5df7ed"
+  :keywords '("faces"))
